
function [SYS,Rp,y0,profiles] = CLFDstatespace(chi,V,tau,rp,rpd,X,Pdep,a,N)

% This function calculates the transfer functions from P -> Te(X) of the PDE:
  % dT/dt = chi*dT^2/dx^2 + V*dT/dx + tau*T + Pdep
%   X = location of the sensors
%   xe = location of the outer edge
%   N = number of discretization points
%   rp = radial coord. of the profile given
%   rpd = radial coord. of the deposition profile
%   chi = diffusion coefficient/profile
%   V  = convection coefficient/profile
%   tau = damping coefficient/profile

%% +++++++++++++++++++ Generate discretization +++++++++

dr = a/N;
r = 0:dr:a;

% Check if profiles are given and interpolate

if length(rp) == 1;
    Chi_e = chi+0*r;
    V_e = V+0*r;
    tau_inv = tau+0*r;
elseif norm(rp - r)==0;
    Chi_e = chi;
    V_e = V;
    tau_inv = tau;
else
    Chi_e = interp1(rp,chi,r,'cubic');
    V_e = interp1(rp,V,r,'cubic');
    tau_inv = interp1(rp,tau,r,'cubic');
end


% interpolate source
if norm(rpd - r)==0;
    P = Pdep;
else P = interp1(rpd,Pdep,r,'cubic');
end

%% Solving the differential equation
%% +++++++++++++++++++ A-matrix ++++++++++++++++++++++++
% Generate r1/2
rhalf = r-dr/2;

%% Generate coefficients diffusion
a_d = rhalf./r.*Chi_e;
b_d = -2*Chi_e;
c_d = (rhalf+dr)./r.*Chi_e;

Achie = dr^-2*spdiags([c_d' b_d' a_d'],-1:1,N,N).';

% BC: gpunt= (g(x+h)-g(x-h))/2h=0
Achie(1,2)   = dr^-2*2*Chi_e(1); 

% Derivative chi_e matrix
a_d_der = -(Chi_e(2:end)-[0,Chi_e(1:end-2)]);
c_d_der =  (Chi_e(2:end)-[0,Chi_e(1:end-2)]);

Achie_der = (2*dr)^-2*spdiags([c_d_der' a_d_der'],[-1,1],N,N).';

% BC: gpunt= (g(x+h)-g(x-h))/2h=0
Achie_der(1,2)   = 0; 

%% Generate coefficients convection 

a_v = -V_e(1:end-1);
b_v = 2*dr./(r(1:end-1)).*V_e(1:end-1)-[0,V_e(1:end-2)]+V_e(2:end);
c_v =  V_e(1:end-1); 

Aconv = 1/(2*dr)*spdiags([c_v' b_v' a_v'],-1:1,N,N).'; 

% BC: gpunt= (g(x+h)-g(x-h))/2h=0
Aconv(1,1) = 0; Aconv(1,2) = 0;

%% Generate coefficients damping
% Adamp  = -diag(tau_inv(1:end-1));
Adamp  = spdiags(-tau_inv(1:end-1).',0,N,N);

%% Combine 
A = Achie + Achie_der + Aconv + Adamp;

%% Input matrix
B(:,1) = P; % deposition profile
% B(N,2) = 0; % Temperature at boundary (not relevant for TF)

%% +++++++++++++++++++ C-matrix ++++++++++++++++++++++++

% Select source and measurement locations
Sensor = interp1(r,r,X,'nearest');
for i = length(Sensor):-1:1;
    indSf(i) = find(r==Sensor(i));
end
if indSf(end) == length(r);
    indSf = indSf(1:end-1);
end

% Measurement locations
Rp = r(indSf); % Measurement positions

C = zeros(length(Sensor),N); j = 1;
for i = indSf 
    C(j,i) = 1;
    j=1+j;
end


A = full(A);

D = zeros(size(C,1),size(B,2));

%% ++++++++++++++++
SYS = ss(A,B,C,D);

% Steady-state value
y0 = -A\B;

profiles = [r(:),Chi_e(:),V_e(:),tau_inv(:),[P(:);0]];
end
