
function [SYS,Rp,y0,profiles] = SlabFDstatespace(chi,V,tau,rp,rpd,X,Pdep,a,N)

% This function calculates the state-space model from P -> Te(X) of the PDE:
  % dT/dt = chi*dT^2/dx^2 + V*dT/dx + tau*T + Pdep
%   X = location of the sensors
%   xe = location of the outer edge
%   N = number of discretization points
%   rp = radial coord. of the profile given
%   rpd = radial coord. of the deposition profile
%   chi = diffusion coefficient/profile
%   V  = convection coefficient/profile
%   tau = damping coefficient/profile

%% +++++++++++++++++++ Generate discretization +++++++++

dr = a/N;
r = 0:dr:a;

% Check if profiles are given and interpolate

if length(rp) == 1;
    Chi_e = chi+0*r;
    V_e = V+0*r;
    tau_inv = tau+0*r;
elseif norm(rp - r)==0;
    Chi_e = chi;
    V_e = V;
    tau_inv = tau;
else
    Chi_e = interp1(rp,chi,r,'cubic');
    V_e = interp1(rp,V,r,'cubic');
    tau_inv = interp1(rp,tau,r,'cubic');
end


% interpolate source
if norm(rpd - r)==0;
    P = Pdep;
else P = interp1(rpd,Pdep,r,'cubic');
end

%% +++++++++++++++++++ A-matrix ++++++++++++++++++++++++
% Generate coefficients    
a_r = Chi_e/(dr^2)+(V_e)/(2*dr);
b_r = -2*Chi_e/(dr^2)-tau_inv;
c_r = Chi_e/(dr^2)-(V_e)/(2*dr);

% Generate matrix
A = spdiags([a_r' b_r' c_r'],-1:1,N,N).';

% Boundary conditions: gpunt= (g(x+h)-g(x-h))/2h=0
A(1,2)   = a_r(1)+c_r(1); 

%% Input matrix
B(:,1) = P; % deposition profile
% B(N,2) = 0; % Temperature at boundary (not relevant for TF)

%% +++++++++++++++++++ C-matrix ++++++++++++++++++++++++

% Select source and measurement locations
Sensor = interp1(r,r,X,'nearest');
for i = length(Sensor):-1:1;
    indSf(i) = find(r==Sensor(i));
end
if indSf(end) == length(r);
    indSf = indSf(1:end-1);
end

% Measurement locations
Rp = r(indSf); % Measurement positions

C = zeros(length(Sensor),N); j = 1;
for i = indSf 
    C(j,i) = 1;
    j=1+j;
end
C = sparse(C);
D = zeros(size(C,1),size(B,2));

A = full(A); B = full(B); C = full(C); D = full(D);

%% ++++++++++++++++
SYS = ss(A,B,C,D);

% Steady-state value
y0 = -A\B;



profiles = [r(:),Chi_e(:),V_e(:),tau_inv(:),[P(:);0]];
end

